@@ -429,7 +429,7 @@ void replace_one_cb(GtkWidget *w) {
 	if(find_len > doc->buffer_size - gh->cursor_pos)
 		return;
 	
-	if(compare_data(&doc->buffer[gh->cursor_pos], find_str, find_len) == 0)
+	if(memcmp(&doc->buffer[gh->cursor_pos], find_str, find_len) == 0)
 		hex_document_set_data(doc, gh->cursor_pos, rep_len, rep_str);
 	
 	if(find_string_forward(doc, gh->cursor_pos+1, find_str, find_len, &offset) == 0)
@@ -593,16 +593,20 @@ void child_changed_cb(GnomeMDI *mdi, HexDocument *doc) {
 
 void view_changed_cb(GnomeMDI *mdi, GtkHex *old_view) {
 	GnomeApp *app;
+	GnomeUIInfo *uiinfo;
 	GtkWidget *shell, *item;
+	HexDocument *doc;
 	gint pos;
 	gint group_item;
+	char *p;
 
 	if(mdi->active_view == NULL)
 		return;
 
 	app = gnome_mdi_get_app_from_view(mdi->active_view);
 	
-	shell = gnome_app_find_menu_pos(app->menubar, _(GROUP_MENU_PATH), &pos);
+	GROUP_MENU_PATH(p);
+	shell = gnome_app_find_menu_pos(app->menubar, p, &pos);
 
 	group_item = GTK_HEX(mdi->active_view)->group_type / 2;
 	shell = gnome_app_find_menu_pos(shell, _(group_type_label[group_item]), &pos);
@@ -611,7 +615,13 @@ void view_changed_cb(GnomeMDI *mdi, GtkHex *old_view) {
 	
 	gtk_menu_shell_activate_item(GTK_MENU_SHELL(shell), item, TRUE);
 
+	uiinfo = gnome_mdi_get_child_menu_info(app);
+	uiinfo = (GnomeUIInfo *)uiinfo[0].moreinfo;
+    doc = HEX_DOCUMENT(gnome_mdi_get_child_from_view(mdi->active_view));
+	gtk_widget_set_sensitive(uiinfo[0].widget, doc->undo_depth > 0);
+
 	gnome_app_install_menu_hints(app, gnome_mdi_get_child_menu_info(app));
+	g_free(p);
 }
 
 void customize_app_cb(GnomeMDI *mdi, GnomeApp *app) {
@@ -679,7 +689,7 @@ void conv_entry_cb(GtkEntry *entry, gint base) {
 	sprintf(buffer, "%lu", val);
 	gtk_entry_set_text(GTK_ENTRY(converter.entry[1]), buffer);
 	
-	sprintf(buffer, "%08x", val);
+	sprintf(buffer, "%08lx", val);
 	gtk_entry_set_text(GTK_ENTRY(converter.entry[2]), buffer);
 	
 	for(i = 0; i < 4; i++) {
