@@ -377,7 +377,7 @@ static void render_hex_lines(GtkHex *gh, gint imin, gint imax) {
 static void render_ascii_lines(GtkHex *gh, gint imin, gint imax) {
 	GtkWidget *w = gh->adisp;
 	gint i, tmp, frm_len;
-	guint cx, cy, cursor_line;
+	guint cursor_line;
 	
 	if( (!GTK_WIDGET_REALIZED(gh)) || (gh->cpl == 0) )
 		return;
@@ -471,7 +471,7 @@ static void draw_shadow(GtkWidget *widget, GdkRectangle *area) {
  * lines we can display according to the current size of the widget
  */
 static void recalc_displays(GtkHex *gh, guint width, guint height) {
-	gint sep_width, total_width = width;
+	gint total_width = width;
 	gint total_cpl, xcpl;
 	gint old_cpl = gh->cpl;
 
@@ -640,7 +640,6 @@ static void scroll_timeout_handler(GtkHex *gh) {
 }
 
 static void hex_button_cb(GtkWidget *w, GdkEventButton *event, GtkHex *gh) {
-	guint mx, my, cx, cy, x;
 	
 	if( (event->type == GDK_BUTTON_RELEASE) &&
 		(event->button == 1) ) {
@@ -821,31 +820,25 @@ static gint gtk_hex_key_press(GtkWidget *w, GdkEventKey *event) {
 				break;
 			default:
 				if((event->keyval >= '0')&&(event->keyval <= '9')) {
-					hex_document_set_byte(gh->document, (gh->document->buffer[gh->cursor_pos] & (0x0F << 4*gh->lower_nibble)) |
-										  ((event->keyval - '0') << ((gh->lower_nibble)?0:4)), gh->cursor_pos);
+					hex_document_set_nibble(gh->document, event->keyval - '0', gh->cursor_pos, gh->lower_nibble);
 					render_byte(gh, gh->cursor_pos);
 					gh->lower_nibble = !gh->lower_nibble;
 					if((!gh->lower_nibble) && (gh->cursor_pos < gh->document->buffer_size-1))
 						gtk_hex_set_cursor(gh, gh->cursor_pos + 1);
-					gtk_hex_data_changed(gh, old_cp, old_cp);
 				}
 				if((event->keyval >= 'A')&&(event->keyval <= 'F')) {
-					hex_document_set_byte(gh->document, (gh->document->buffer[gh->cursor_pos] & (0x0F << 4*gh->lower_nibble)) |
-										  ((event->keyval - 'A' + 10) << ((gh->lower_nibble)?0:4)), gh->cursor_pos);
+					hex_document_set_nibble(gh->document, event->keyval - 'A' + 10, gh->cursor_pos, gh->lower_nibble);
 					render_byte(gh, gh->cursor_pos);
 					gh->lower_nibble = !gh->lower_nibble;
 					if((!gh->lower_nibble) && (gh->cursor_pos < gh->document->buffer_size-1))
 						gtk_hex_set_cursor(gh, gh->cursor_pos + 1);
-					gtk_hex_data_changed(gh, old_cp, old_cp);
 				}
 				if((event->keyval >= 'a')&&(event->keyval <= 'f')) {
-					hex_document_set_byte(gh->document, (gh->document->buffer[gh->cursor_pos] & (0x0F << 4*gh->lower_nibble)) |
-										  ((event->keyval - 'a' + 10) << ((gh->lower_nibble)?0:4)), gh->cursor_pos);
+					hex_document_set_nibble(gh->document, event->keyval - 'a' + 10, gh->cursor_pos, gh->lower_nibble);
 					render_byte(gh, gh->cursor_pos);
 					gh->lower_nibble = !gh->lower_nibble;
 					if((!gh->lower_nibble) && (gh->cursor_pos < gh->document->buffer_size-1))
 						gtk_hex_set_cursor(gh, gh->cursor_pos + 1);
-					gtk_hex_data_changed(gh, old_cp, old_cp);
 				}
 				break;      
 			}
@@ -865,7 +858,6 @@ static gint gtk_hex_key_press(GtkWidget *w, GdkEventKey *event) {
 					render_byte(gh, gh->cursor_pos);
 					old_cp = gh->cursor_pos;
 					gtk_hex_set_cursor(gh, gh->cursor_pos + 1);
-					gtk_hex_data_changed(gh, old_cp, old_cp);
 				}
 				break;
 			}
@@ -990,7 +982,6 @@ static void gtk_hex_class_init(GtkHexClass *klass) {
 }
 
 static void gtk_hex_init(GtkHex *gh) {
-	GtkWidget *widget = GTK_WIDGET(gh);
 	
 	gh->scroll_timeout = -1;
 	
@@ -1162,6 +1153,8 @@ gint gtk_hex_get_cursor(GtkHex *gh) {
 guchar gtk_hex_get_byte(GtkHex *gh, guint offset) {
 	if((offset >= 0) && (offset < gh->document->buffer_size))
 		return gh->document->buffer[offset];
+
+	return 0;
 }
 
 /*
@@ -1172,14 +1165,6 @@ void gtk_hex_set_group_type(GtkHex *gh, guint gt) {
 	gtk_widget_queue_resize(GTK_WIDGET(gh));
 }
 
-void gtk_hex_data_changed(GtkHex *gh, gint start, gint end) {
-	gh->document->change_data.start = start;
-	gh->document->change_data.end = end;
-	
-	if(gh->document)
-		hex_document_changed(HEX_DOCUMENT(gh->document), &gh->document->change_data);
-}
-
 /*
  * sets font for displaying data
  */
