@@ -55,8 +55,8 @@ int main(int argc, char **argv) {
     gnome_mdi_set_menubar_template(mdi, main_menu);
 
     /* and document menu and document list paths */
-    gnome_mdi_set_child_menu_path(mdi, _(CHILD_MENU_PATH));
-    gnome_mdi_set_child_list_path(mdi, _(CHILD_LIST_PATH));
+    gnome_mdi_set_child_menu_path(mdi, CHILD_MENU_PATH);
+    gnome_mdi_set_child_list_path(mdi, CHILD_LIST_PATH);
 
     /* connect signals */
     gtk_signal_connect(GTK_OBJECT(mdi), "remove_child", GTK_SIGNAL_FUNC(remove_doc_cb), NULL);
@@ -71,16 +71,12 @@ int main(int argc, char **argv) {
     gnome_mdi_set_mode(mdi, mdi_mode);
 
     /* restore state from previous session */
-    if (GNOME_CLIENT_CONNECTED (client)) {
+    if (gnome_client_get_flags (client) & GNOME_CLIENT_RESTORED) {
 
 		gnome_config_push_prefix (gnome_client_get_config_prefix (client));
-
-		restarted= gnome_config_get_bool ("General/saved_session=0");
 		
-		if (restarted)
-			restarted = gnome_mdi_restore_state (mdi, "Session", (GnomeMDIChildCreator)hex_document_new_from_config);
-				
-
+		restarted= gnome_mdi_restore_state (mdi, "Session", (GnomeMDIChildCreator)hex_document_new_from_config);		
+		
 		gnome_config_pop_prefix ();
 	}
 
